@@ -6,8 +6,8 @@ describe Dotenv do
       let(:env_files) { [] }
 
       it 'defaults to .env' do
-        Dotenv::Environment.should_receive(:new).with(expand('.env')).
-          and_return(double(:apply => {}))
+        expect(Dotenv::Environment).to receive(:new).with(expand('.env')).
+          and_return(double(:apply => {}, :apply! => {}))
         subject
       end
     end
@@ -17,9 +17,9 @@ describe Dotenv do
 
       it 'expands the path' do
         expected = expand("~/.env")
-        File.stub(:exists?){ |arg| arg == expected }
-        Dotenv::Environment.should_receive(:new).with(expected).
-          and_return(double(:apply => {}))
+        allow(File).to receive(:exist?){ |arg| arg == expected }
+        expect(Dotenv::Environment).to receive(:new).with(expected).
+          and_return(double(:apply => {}, :apply! => {}))
         subject
       end
     end
@@ -72,16 +72,26 @@ describe Dotenv do
     context 'when one file exists and one does not' do
       let(:env_files) { ['.env', '.env_does_not_exist'] }
 
-      it 'raises an Errno::ENOENT error and does not load any files' do
-        expect do
-          expect do
-            subject
-          end.to raise_error(Errno::ENOENT)
-        end.to_not change { ENV.keys }
+      it 'raises an Errno::ENOENT error' do
+        expect { subject }.to raise_error(Errno::ENOENT)
       end
     end
   end
 
+  describe 'overload' do
+    let(:env_files) { [fixture_path('plain.env')] }
+    subject { Dotenv.overload(*env_files) }
+    it_behaves_like 'load'
+
+    it 'overrides any existing ENV variables' do
+      ENV['OPTION_A'] = 'predefined'
+
+      subject
+
+      expect(ENV['OPTION_A']).to eq('1')
+    end
+  end
+
   def fixture_path(name)
     File.join(File.expand_path('../fixtures', __FILE__), name)
   end
